@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for AFNIC
 ##
-## Copyright (c) 2006,2008-2010,2012-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,27 +10,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Data::Contact::AFNIC;
 
-use utf8;
 use strict;
-use warnings;
-
+use encoding 'iso-8859-15';
 use base qw/Net::DRI::Data::Contact/;
-
-use Email::Valid;
+__PACKAGE__->mk_accessors(qw(legal_form legal_form_other legal_id jo trademark key birth));
 
 use Net::DRI::Exception;
-use Net::DRI::Util;
 
-__PACKAGE__->register_attributes(qw(firstname legal_form legal_form_other legal_id legal_id_type jo trademark birth vat qualification obsoleted));
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
-=encoding utf8
-
 =head1 NAME
 
 Net::DRI::Data::Contact::AFNIC - Handle AFNIC contact data for Net::DRI
@@ -44,14 +41,13 @@ AFNIC specific data.
 
 The following accessors/mutators can be called in chain, as they all return the object itself.
 
-=head2 firstname()
+=head2 roid()
 
-Please note that for AFNIC data, the name() must be only the lastname, hence this extra firstname() method needed for contacts being individuals
+NIC handle for the contact
 
 =head2 legal_form()
 
-for an organization, either 'A' or 'association' for non profit organization, 'S' or 'company' for company or 'other' for other types;
-this must be set for contacts being moral entities
+for an organization, either 'A' for non profit organization or 'S' for company
 
 =head2 legal_form_other()
 
@@ -63,19 +59,17 @@ French SIREN/SIRET of organization
 
 =head2 jo()
 
-reference to an hash with 4 keys storing details about «Journal Officiel» :
+reference to an hash with 4 keys storing details about Journal Officiel :
 date_declaration (Declaration date), date_publication (Publication date),
 number (Announce number) and page (Announce page)
 
-a waldec key can also be present for the waldec id
-
 =head2 trademark()
 
 for trademarks, its number
 
-=head2 vat()
+=head2 key()
 
-vat number (not used by registry for now)
+registrant invariant key
 
 =head2 birth()
 
@@ -100,7 +94,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2010,2012-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -114,73 +108,88 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-our $LETTRES=qr(A-Z\x{00C0}\x{00C2}\x{00C7}\x{00C8}\x{00C9}\x{00CA}\x{00CB}\x{00CE}\x{00CF}\x{00D4}\x{00D9}\x{00DB}\x{00DC}\x{0178}\x{00C6}\x{0152}a-z\x{00E0}\x{00E2}\x{00E7}\x{00E8}\x{00E9}\x{00EA}\x{00EB}\x{00EE}\x{00EF}\x{00F4}\x{00F9}\x{00FB}\x{00FC}\x{00FF}\x{00E6}\x{0153});
-our $NOM_LIBRE_ITEM=qr{[${LETTRES}0-9\(\)\.\[\]\?\+\*#&/!\@',><":-]+};
+our $LETTRES=qr{A-ZܾƼa-z};
+our $NOM_LIBRE_ITEM=qr{[${LETTRES}0-9\(\)\.\[\]\?\+\*#&/!\@',><":-]+'};
 our $NOM_PROPRE_ITEM=qr{[${LETTRES}]+(('?(?:[${LETTRES}]+(?:\-?[${LETTRES}]+)?)+)|(?:\.?))};
 our $NOM_PROPRE=qr{${NOM_PROPRE_ITEM}( +${NOM_PROPRE_ITEM})*};
 our $ADRESSE_ITEM=qr{[${LETTRES}0-9\(\)\./',"#-]+};
-our $NOM_COMMUNE_ITEM=qr{[${LETTRES}]+(?:['-]?[${LETTRES}]+)*};
 
 sub is_nom_libre { return shift=~m/^(?:${NOM_LIBRE_ITEM} *)*[${LETTRES}0-9]+(?: *${NOM_LIBRE_ITEM}*)*$/; }
 sub is_adresse   { return shift=~m/^(?:${ADRESSE_ITEM} *)*[${LETTRES}]+(?: *${ADRESSE_ITEM})*$/; }
-sub is_commune   { return shift=~m/^${NOM_COMMUNE_ITEM}(?:(?:(?: *\/ *)|(?: +))${NOM_COMMUNE_ITEM})*(?: +(?:[cC][eE][dD][eE][xX]|[cC][dD][xX])(?: +[0-9]+)?)?$/; }
 sub is_code_fr   { return shift=~m/^(?:FR|RE|MQ|GP|GF|TF|NC|PF|WF|PM|YT)$/; }
-sub is_dep_fr    { return shift=~m/^(?:0[1-9])|(?:[1345678][0-9])|(?:2[1-9ABab])|(?:9[0-5])|(?:97[1-5])|(?:98[5-8])$/; }
 
 sub validate
 {
  my ($self,$change)=@_;
  $change||=0;
-
- $self->SUPER::validate(1); ## will trigger an Exception if problem
-
  my @errs;
- push @errs,'srid' if ($self->srid() && $self->srid()!~m/^[A-Z]+(?:[1-9][0-9]*)?(?:-FRNIC)?$/i);
- push @errs,'name' if ($self->name() && ($self->name()!~m/^${NOM_PROPRE}$/ || ! is_nom_libre($self->name())));
- push @errs,'firstname' if ($self->firstname() && $self->firstname()!~m/^${NOM_PROPRE}$/);
+
+## NIC handle
+ push @errs,'roid' if ($self->roid() && $self->roid()!~m/^[A-Z]+(?:[1-9][0-9]*)?-FRNIC$/i);
+
+ push @errs,'name' if ($self->name() && $self->name()!~m/^${NOM_PROPRE} *, *${NOM_PROPRE}$/);
  push @errs,'org'  if ($self->org()  && ! is_nom_libre($self->org()));
 
- push @errs,'legal_form'       if ($self->legal_form()       && $self->legal_form()!~m/^(?:company|association|other)$/);
- push @errs,'legal_form_other' if ($self->legal_form_other() && ! is_nom_libre($self->legal_form_other()));
- if ($self->legal_id_type())
+ my $rs=$self->street();
+ push @errs,'street' if ($rs && ((ref($rs) ne 'ARRAY') || (@$rs > 3) || (grep { ! is_adresse($_) } @$rs)));
+
+ push @errs,'city' if ($self->city() && $self->city()!~m/^${NOM_PROPRE}$/);
+
+ my $cc=$self->cc();
+ my $isccfr=0;
+ if ($cc)
  {
-  push @errs,'legal_id_type' if $self->legal_id_type()!~m/^(?:siren|duns|local)$/;
-  push @errs,'legal_id'      if ($self->legal_id() && $self->legal_id_type() eq 'sirent' && $self->legal_id()!~m/^[0-9]{9}(?:[0-9]{5})?$/);
+  push @errs,'cc' if !exists($Net::DRI::Util::CCA2{uc($cc)});
+  $isccfr=is_code_fr(uc($cc));
  }
+ my $pc=$self->pc();
+ if ($pc)
+ {
+  if ($isccfr)
+  {
+   push @errs,'pc' unless $pc=~m/^[0-9]{5}$/;
+  } else
+  {
+   push @errs,'pc' unless $pc=~m/^[-0-9A-Za-z]+$/;
+  }
+ }
+
+ push @errs,'legal_form'       if ($self->legal_form()       && $self->legal_form()!~m/^[AS]$/);
+ push @errs,'legal_form_other' if ($self->legal_form_other() && $self->legal_form_other()!~m/^${NOM_PROPRE}$/);
+ push @errs,'legal_id'         if ($self->legal_id()         && $self->legal_id()!~m/^[0-9]{9}(?:[0-9]{5})?$/);
 
  my $jo=$self->jo();
  if ($jo)
  {
   if ((ref($jo) eq 'HASH') && exists($jo->{date_declaration}) && exists($jo->{date_publication}) && exists($jo->{number}) && exists ($jo->{page}))
   {
-   push @errs,'jo' unless ($jo->{date_declaration}=~m!^[0-9]{2}/[0-9]{2}/[0-9]{4}$! || $jo->{date_declaration}=~m!^[0-9]{4}-[0-9]{2}-[0-9]{2}$!);
-   push @errs,'jo' unless ($jo->{date_publication}=~m!^[0-9]{2}/[0-9]{2}/[0-9]{4}$! || $jo->{date_publication}=~m!^[0-9]{4}-[0-9]{2}-[0-9]{2}$!);
-   push @errs,'jo' unless $jo->{number}=~m/^[1-9][0-9]*$/;
-   push @errs,'jo' unless $jo->{page}=~m/^[1-9][0-9]*$/;
+   push @errs,'jo' unless $jo->{date_declaration}=~m!^[0-9]{2}/[0-9]{2}/[0-9]{4}$!;
+   push @errs,'jo' unless $jo->{date_publication}=~m!^[0-9]{2}/[0-9]{2}/[0-9]{4}$!;
+   push @errs,'jo' unless $jo->{number}=~m/^[1-9][0-9]+$/;
+   push @errs,'jo' unless $jo->{page}=~m/^[1-9][0-9]+$/;
   } else
   {
    push @errs,'jo';
   }
  }
 
- push @errs,'vat'       if ($self->vat()       && !Net::DRI::Util::xml_is_token($self->vat()));
  push @errs,'trademark' if ($self->trademark() && $self->trademark()!~m/^[0-9]*[A-Za-z]*[0-9]+$/);
 
+ push @errs,'key' if ($self->key() && $self->key()!~m/^[A-Za-z]{8}-[1-9][0-9]{2}$/);
+
  my $birth=$self->birth();
  if ($birth)
  {
   if ((ref($birth) eq 'HASH') && exists($birth->{date}) && exists($birth->{place}))
   {
-   push @errs,'birth' unless ((ref($birth->{date}) eq 'DateTime') || $birth->{date}=~m!^[0-9]{4}-[0-9]{2}-[0-9]{2}$! || $birth->{date}=~m!^[0-9]{2}/[0-9]{2}/[0-9]{4}$!);
-   push @errs,'birth' unless (($birth->{place}=~m/^[A-Za-z]{2}$/ && ! is_code_fr($birth->{place})) || ($birth->{place}=~m/^(?:[0-9]{5}|) *, *(.+)$/ && is_commune($1)));
+   push @errs,'birth' unless $birth->{date}=~m!^[0-9]{2}/[0-9]{2}/[0-9]{4}$!;
+   push @errs,'birth' unless $birth->{place}=~m!^(?:[A-Za-z]{2}|[0-9]{2}(?:[0-9]{3})* *, *${NOM_PROPRE})$!;
   } else
   {
    push @errs,'birth';
   }
  }
 
- my $isccfr=$self->cc()? is_code_fr(uc($self->cc())) : 0;
-
  ## Not same checks as AFNIC, but we will translate to their format when needed, better to standardize on EPP
  if ($self->voice())
  {
@@ -194,61 +203,20 @@ sub validate
  }
  push @errs,'email' if ($self->email() && !Email::Valid->rfc822($self->email()));
 
+ ## No need to test type, we will set it up automatically when needed (organisation empty => PP, otherwise PM)
  ## Maintainer is not tied to contact
-
+ 
  push @errs,'disclose' if ($self->disclose() && $self->disclose()!~m/^[ONY]$/i);
 
- my $q=$self->qualification();
- if (defined $q)
- {
-  push @errs,'qualification' if ref $q ne 'HASH' || grep { ! /^(?:identification|reachable)$/ } keys %$q;
- }
-
  Net::DRI::Exception::usererr_invalid_parameters('Invalid contact information: '.join('/',@errs)) if @errs;
  return 1; ## everything ok.
 }
 
-sub validate_registrant
+## Test for registrants
+sub validate_is_french
 {
  my $self=shift;
- my @errs;
- my $rs=$self->street();
- push @errs,'street' if ($rs && ((ref($rs) ne 'ARRAY') || (@$rs > 3) || (grep { ! is_adresse($_) } @$rs)));
- push @errs,'city' if ($self->city() && ! is_commune($self->city()));
-
- my $cc=$self->cc();
- my $isccfr=0;
- if ($cc)
- {
-  push @errs,'cc' if !exists($Net::DRI::Util::CCA2{uc($cc)});
-  $isccfr=is_code_fr(uc($cc));
- }
-
- my $pc=$self->pc();
- if ($pc)
- {
-  if ($isccfr)
-  {
-   push @errs,'pc' unless $pc=~m/^[0-9]{5}$/;
-  } else
-  {
-   push @errs,'pc' unless $pc=~m/^[-0-9A-Za-z ]+$/;
-  }
- }
-
- Net::DRI::Exception::usererr_invalid_parameters('Invalid contact information: '.join('/',@errs)) if @errs;
- return 1; ## everything ok.
-}
-
-sub init
-{
- my ($self,$what,$ndr)=@_;
- my $pn=$ndr->protocol()->name();
- if ($what eq 'create' && $pn eq 'EPP')
- {
-  $self->srid('AUTO') unless defined($self->srid()); ## we can not choose the ID
- }
- return;
+ Net::DRI::Exception::usererr_invalid_parameters('Registrant contact must be French') unless is_code_fr(uc($self->cc()));
 }
 
 ####################################################################################################
