@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Handling of contact data for .SE
-## Contributed by Elias Sidenbladh and Ulrich Wisser from NIC SE
+## Contributed by Elias Sidenbladh from NIC SE
 ##
-## Copyright (c) 2006-2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,22 +11,26 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+#  
+#
 #########################################################################################
 
 package Net::DRI::Data::Contact::SE;
 
 use strict;
-use warnings;
 use base qw/Net::DRI::Data::Contact/;
+__PACKAGE__->mk_accessors(qw(orgno));
+
 use Net::DRI::Exception;
 
-__PACKAGE__->register_attributes(qw(orgno vatno));
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Data::Contact::SE - Handle .SE contact data for Net::DRI
+Net::DRI::Data::Contact::SE - Handling of contact data for .SE
 
 =head1 DESCRIPTION
 
@@ -62,7 +66,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -82,31 +86,14 @@ sub validate
  $change||=0;
  my @errs;
 
- # call parent validate, will trigger an Exception if problem
  $self->SUPER::validate($change); ## will trigger an Exception if problem
 
- # validate our extensions
- push @errs, 'orgno' if ( $self->orgno() && $self->orgno() !~ m/^\[[A-Z]{2}\]/ );
+ push @errs,'orgno' if ($self->orgno() && $self->orgno()!~m/^\[[A-Z]+\][^\s].+$/);
 
- # throw exception if errors detected
- Net::DRI::Exception::usererr_invalid_parameters( 'Invalid contact information: ' . join( '/', @errs ) ) if @errs;
+ Net::DRI::Exception::usererr_invalid_parameters('Invalid contact information: '.join('/',@errs)) if @errs;
 
- # done, everything ok
- return 1;
+ return 1; ## everything ok.
 }
 
-sub init
-{
- my ($self,$what,$ndr)=@_;
-
- if ($what eq 'create')
- {
-  my $a=$self->auth();
-  $self->auth({pw=>''}) unless ($a && (ref($a) eq 'HASH') && exists($a->{pw}));
- }
- return;
-}
-
-
 ####################################################################################################
 1;
