@@ -1,6 +1,7 @@
-## Domain Registry Interface, NASK (.PL) EPP extensions (draft-zygmuntowicz-epp-pltld-03)
+## Domain Registry Interface, NASK (.PL) EPP extensions
+## http://www.dns.pl/porozumienie/draft-zygmuntowicz-epp-pltld-02.txt
 ##
-## Copyright (c) 2006,2008,2009,2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +11,26 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-####################################################################################################
+#
+# 
+#
+#########################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::PL;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::PL;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::PL - .PL EPP extensions (draft-zygmuntowicz-epp-pltld-03) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::PL - .PL EPP extensions for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -49,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009,2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -62,20 +67,33 @@ See the LICENSE file that comes with this distribution for more details.
 =cut
 
 ####################################################################################################
-
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({ extdom => 'http://www.dns.pl/NASK-EPP/extdom-1.0',
-             extcon => 'http://www.dns.pl/NASK-EPP/extcon-1.0',
-            # future     => 'http://www.dns.pl/NASK-EPP/future-1.0', ## TODO
-          });
- $self->capabilities('host_update','name',undef); ## No change of hostnames
- $self->factories('contact',sub { return Net::DRI::Data::Contact::PL->new(); });
- return;
-}
+ my $h=shift;
+ my $c=ref($h) || $h;
 
-sub default_extensions { return qw/SecDNS PL::Domain PL::Contact PL::Message PL::Report/; } ## TODO: PL::Future
+ my ($drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::PL::Domain'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::PL::Contact'}=1;
+## $e{'Net::DRI::Protocol::EPP::Extensions::PL::Future'}=1; ## TODO
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+
+ $self->{ns}->{pl_domain}=['urn:nask:params:xml:ns:extdom-1.0','extdom-1.0.xsd'];
+ $self->{ns}->{pl_contact}=['urn:nask:params:xml:ns:extcon-1.0','extcon-1.0.xsd'];
+## $self->{ns}->{future}=['http://www.dns.pl/NASK-EPP/future-1.0','future-1.0.xsd'];
+
+ my $rcapa=$self->capabilities();
+ delete($rcapa->{host_update}->{name}); ## No change of hostnames
+
+ my $rfact=$self->factories();
+ $rfact->{contact}=sub { return Net::DRI::Data::Contact::PL->new(); };
+
+ bless($self,$c); ## rebless
+ return $self;
+}
 
 ####################################################################################################
 1;
