@@ -1,6 +1,6 @@
 ## Domain Registry Interface, SMTP Transport
 ##
-## Copyright (c) 2006,2007,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,20 +10,23 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Transport::SMTP;
 
 use strict;
-use warnings;
-
-use base qw/Net::DRI::Transport/;
+use base qw/Net::DRI::Transport/; ## we are a subclass
 
 use Net::SMTP;
 use Email::Valid;
 
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -52,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2007,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,13 +67,18 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+###################################################################################################
 
 sub new
 {
- my ($class,$ctx,$rp)=@_;
- my %opts=%$rp;
- my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
+ my $drd=shift;
+ my $po=shift;
+
+ my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my $self=$class->SUPER::new(\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->has_state(0); ## We could be stateful by keeping a live connection to the SMTP host. But it would be useful only for high volumes
  $self->is_sync(0);
  $self->name('smtp');
@@ -85,17 +93,20 @@ sub new
 
  $self->{transport}=\%t;
 
+ ## Bless again, but now in this package
+ bless($self,$class);
  return $self;
 }
 
 ####################################################################################################
+ 
+sub end {}
 
-sub end { }
-
-sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
+sub send
 {
- my ($self,$ctx,$tosend)=@_;
- return $self->SUPER::send($ctx,$tosend,\&_send,undef);
+ my ($self,$tosend)=@_;
+ 
+ $self->SUPER::send($tosend,\&_send,undef);
 }
 
 sub _send
@@ -107,21 +118,20 @@ sub _send
  my $head=$mime->head();
  $head->add('Cc',$rt->{cc})   if exists($rt->{cc});
  $head->add('Bcc',$rt->{bcc}) if exists($rt->{bcc});
-
+ 
  my %rcpts=map { $_ => 1 } map { $head->get_all($_) } ('To','Cc','Bcc');
  $head->delete('Bcc');
 
  my $smtp=Net::SMTP->new($rt->{smtphost});
  my $ok=$smtp->mail($head->get('From'),Bits=>8) && $smtp->to(keys(%rcpts)) && $smtp->data($mime->stringify()) && $smtp->quit();
-
+ 
  Net::DRI::Exception->die(0,'transport/socket',4,'Unable to send message') unless $ok;
  return 1;
 }
 
 sub receive
 {
- my ($self,$ctx,$count)=@_;
- return;
+
 }
 
 ####################################################################################################
